#
# spec file for package wireless-regdb
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!_firmwaredir:%define _firmwaredir /lib/firmware}

Name:           wireless-regdb
Version:        20250220
Release:        1.1
Summary:        802.11 regulatory domain database
License:        ISC
URL:            https://wireless.wiki.kernel.org/en/developers/regulatory/wireless-regdb
Source:         %{name}-%{version}.tar.gz
BuildArch:      noarch

%description
The 802.11 regulatory domain database is used by CRDA and provides allowed
frequency ranges for 802.11 wireless drivers.

%prep
%autosetup

%build

%install
%make_install FIRMWARE_PATH="%{_firmwaredir}"

%files
%license LICENSE
%doc README
%{_firmwaredir}/regulatory.db
%{_firmwaredir}/regulatory.db.p7s
%dir %{_prefix}/lib/crda
%{_prefix}/lib/crda/regulatory.bin
%dir %{_prefix}/lib/crda/pubkeys
%{_prefix}/lib/crda/pubkeys/*pem
%{_mandir}/man5/regulatory.db.5%{?ext_man}
%{_mandir}/man5/regulatory.bin.5%{?ext_man}

%changelog
* Sat Mar 29 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250220 (boo#1240356):
  * Update regulatory info for Oman (OM)
  * Update regulatory rules for Iran (IR) on both 2.4 and 5Ghz for 2021
  * Update regulatory info for Cayman Islands (KY) for 2024
  * Update regulatory rules for Austria (AT)
  * Permit 320 MHz bandwidth in 6 GHz band in ETSI/CEPT
  * Update regulatory rules for Armenia (AM) on 2.4 and 5 GHz
  * Update regulatory info for Azerbaijan (AZ) on 6GHz for 2024
* Thu Jan  4 2024 Martin Pluskal <mpluskal@suse.com>
- Update to version 20231201:
  * wireless-regdb: Update keys and maintainer information
* Mon Sep 18 2023 Ivan Ivanov <ivan.ivanov@suse.com>
- Define %%{_firmwaredir} if not defined. This fixes RPM build errors.
* Thu Sep  7 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230901:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory rules for Australia (AU) for June 2023
* Fri Jul 28 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230721:
  * wireless-regdb: Update regulatory info for Türkiye (TR)
  * wireless-regdb: Update regulatory rules for Egypt (EG) from March 2022 guidelines
* Fri Jun  9 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230601:
  * wireless-regdb: Update regulatory rules for Philippines (PH)
* Tue May  9 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230503:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory rules for Hong Kong (HK)
  * wireless-regdb: update regulatory rules for India (IN)
  * wireless-regdb: Update regulatory rules for Russia (RU). Remove DFS requirement.
  * Update regulatory info for Russia (RU) on 6GHz
* Tue Mar  7 2023 Martin Pluskal <mpluskal@suse.com>
- Update to version 20230213:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory info for Russia (RU) on 5GHz
* Tue Dec  6 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20221205:
  * wireless-regdb: Update regulatory rules for Japan (JP) on 6GHz
  * wireless-regdb: Update regulatory rules for Japan (JP) on 5GHz
* Mon Nov 14 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20221012:
  * wireless-regdb: update regulatory rules for Switzerland (CH)
  * wireless-regdb: Update regulatory rules for Brazil (BR)
* Wed Aug 17 2022 dmueller@suse.com
- Update to version 20220812:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: update 5 GHz rules for PK and add 60 GHz rule
  * wireless-regdb: add 5 GHz rules for GY
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Unify 6 GHz rules for EU contries
  * wireless-regdb: Remove AUTO-BW from 6 GHz rules
  * wireless-regdb: update regulatory rules for Bulgaria (BG) on 6GHz
  * Regulatory update for 6 GHz operation in FI
  * Regulatory update for 6 GHz operation in United States (US)
  * Regulatory update for 6 GHz operation in Canada (CA)
* Wed Jun 15 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220606:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Unify 6 GHz rules for EU contries
  * wireless-regdb: Remove AUTO-BW from 6 GHz rules
* Tue May 31 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220527:
  * wireless-regdb: update regulatory rules for Bulgaria (BG) on 6GHz
  * Regulatory update for 6 GHz operation in FI
  * Regulatory update for 6 GHz operation in United States (US)
  * Regulatory update for 6 GHz operation in Canada (CA)
* Tue Apr 19 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220408:
  * wireless-regdb: add db files missing from previous commit
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory rules for Australia (AU)
  * wireless-regdb: add missing spaces for US S1G rules
* Mon Mar 28 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220324:
  * wireless-regdb: Update regulatory rules for Israel (IL)
* Tue Mar  8 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220218:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory rules for the Netherlands (NL) on 6GHz
  * wireless-regdb: Update regulatory rules for China (CN)
  * wireless-regdb: Update regulatory rules for South Korea (KR)
  * Revert "wireless-regdb: Update regulatory rules for South Korea (KR)"
  * wireless-regdb: Update regulatory rules for Spain (ES) on 6GHz
  * wireless-regdb: add 802.11ah bands to world regulatory domain
  * wireless-regdb: add support for US S1G channels
  * wireless-regdb: Update regulatory rules for France (FR) on 6 and 60 GHz
  * wireless-regdb: Update regulatory rules for South Korea (KR)
* Tue Feb  8 2022 Martin Pluskal <mpluskal@suse.com>
- Update to version 20220108:
  * wireless-regdb: Update regulatory rules for Croatia (HR) on 6GHz
* Wed Dec 15 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20211209:
  * wireless-regdb: Raise DFS TX power limit to 250 mW (24 dBm) for the US
* Tue Oct 12 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210828:
  * wireless-regdb: update regulatory database based on preceding changes
  * Update regulatory rules for Ecuador (EC)
  * wireless-regdb: Update regulatory rules for Norway (NO) on 6 and 60 GHz
  * wireless-regdb: Update regulatory rules for Germany (DE) on 6GHz
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: reduce bandwidth for 5730-5850 and 5850-5895 MHz in US
  * wireless-regdb: remove PTMP-ONLY from 5850-5895 MHz for US
  * wireless-regdb: recent FCC report and order allows 5850-5895 immediately
  * wireless-regdb: update 5725-5850 MHz rule for GB
* Wed Apr 28 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210421:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: re-add source url and info for CU
* Tue Apr 13 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210407:
  * wireless-regdb: Update regulatory rules for Cuba (CU) on 5GHz
  * wireless-regdb: Do not hardcode 'sforshee' in the certificate commonName
* Wed Feb 17 2021 Martin Pluskal <mpluskal@suse.com>
- Update to version 20210129:
  * wireless-regdb: Update regulatory rules for Ukraine (UA)
  * wireless-regdb: update CNAF regulation url for ES
* Mon Dec 14 2020 Ludwig Nussel <lnussel@suse.de>
- leverage %%{_firmwaredir} to install firmware into correct location (boo#1029961)
* Thu Nov 26 2020 dmueller@suse.com
- Update to version 20201120:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: Update regulatory rules for Kazakhstan (KZ)
  * wireless-regdb: update 5.8 GHz regulatory rule for GB
  * wireless-regdb: Update regulatory rules for Pakistan (PK) on 5GHz
  * wireless-regdb: Update regulatory rules for Croatia (HR)
  * wireless-regdb: restore channel 12 & 13 limitation in the US
  * wireless-regdb: update regulatory rules for Egypt (EG)
* Fri Jun  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Wed May  6 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20200429:
  * wireless-regdb: update regulatory database based on preceding changes
  * wireless-regdb: update rules for US on 2.4/5G
  * GB: Extend to cover DMG channels 5 & 6
  * wireless-regdb: Update regulatory rules for Singapore (SG)
  * wireless-regdb: Update regulatory rules for Indonesia (ID)
* Mon Mar 23 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 20191029:
  * regdb: fix compatibility with python2
  * wireless-regdb: Update regulatory rules for Russia (RU)
  * wireless-regdb: Harmonize ranges of CEPT countries (stand of July 2019)
  * wireless-regdb: Fix ranges of EU countries as they are harmonized since 2014
  * wireless-regdb: Extend 5470-5725 MHz range to 5730 MHz for Taiwan (TW)
  * wireless-regdb: Fix overlapping ranges for Switzerland and Liechtenstein
  * wireless-regdb: update regulatory database based on preceding changes
- Switch to _service
- Update project url
* Thu Jun 13 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2019.06.03 (boo#1138177):
  * Expand 60 GHz band for Japan to 57-66 GHz
  * update source of information for CU
  * Update regulatory rules for South Korea
  * Update regulatory rules for Japan (JP) on 5GHz
  * update source of information for ES
* Mon May  6 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 2019.03.01 (boo#1134213):
  * Sync IN with G.S.R. 1048(E)
  * Update regulatory rules for Sweden (SE) on 2.4/5/60 GHz
  * update 60ghz band rules for us
  * Add 5725-5875 MHz rule for Portugal (PT)
  * add URLs in README
  * delete outdated comment for DE
* Thu Jan 10 2019 Martin Pluskal <mpluskal@suse.com>
- Update version to 2018.10.24 (boo#1121466):
  * remove dependency to python attr
  * Sync DE with ETSI EN 301 893 V2.1.1
  * Sync FR with ETSI EN 301 893 V2.1.1
- Changes for version 2018-09-07:
  * update source of info for CU and ES
  * update regulatory rules for Switzerland (CH), and Liechtenstein
  * Update regulatory rules for Finland (FI) on 5GHz (SRD devices)
  * update rules for Hungary (HU) on 2.4/5/60G, 5725-5875MHz
* Thu Aug 30 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 2018.05.31 (boo#1106528):
  * Fix power limit in 5725-5785 GHz rule for France
* Thu May 31 2018 mpluskal@suse.com
- Update to version 2018.05.09 (boo#1095397):
  * Updated regulatory database for France and Panama
  * Fixes in python3 scripts
* Fri Jan  5 2018 mpluskal@suse.com
- Update to version 2017.12.23 (boo#1074838):
  * update regulatory database based on preceding changes
  * Document regulatory.db in the manual page
  * Install regulatory.db and regulatory.db.p7s to /lib/firmware
  * Better support for generating public certificates
  * Add sforshee's x509 certificate
  * Restore generation of old format database files
  * regdb: write firmware file format (version code 20)
* Sat Mar 18 2017 mpluskal@suse.com
- Update to 2017.03.07 (boo#1030085):
  * Update rules for Australia (AU) and add 60GHz rules
  * Update 5 GHz rules for Canada
  * Remove DFS requirement for India (IN)
* Sun Jun 12 2016 mpluskal@suse.com
- Update to 2016.06.10:
  * Republic of Korea: Add 60GHz regulatory rules
* Sat May  7 2016 mpluskal@suse.com
- Update to 2016.05.02:
  * wireless-regdb: Update regulatory references for Germany (DE)
  * Update the regulatory rules for Bulgaria (BG)
  * Update regulatory rules for NL as per ETSI EN 300 440-1
  * wireless-regdb: Update regulatory rules for Germany (DE) on 5GHz
* Sat Feb 13 2016 afaerber@suse.de
- Explicitly require xz, fixing tar errors for SLE11 builds
- Work around a mismatch of lib vs. lib64 on SLE11 x86_64
* Tue Feb  9 2016 mpluskal@suse.com
- Update to 2016.02.08:
  * add 2.4GHz regulatory rules for Cuba (CU)
* Tue Dec 22 2015 mpluskal@suse.com
- Update to 2015.12.14:
  * fix world regdomain
  * Update regulatory rules for Finland (FI)
* Thu Nov 12 2015 mpluskal@suse.com
- Update to 2015.10.22:
  * Update regulatory rules for Croatia (HR)
  * Add 160 MHz channel bandwidth for Greenland (GL)
* Fri Oct 16 2015 mpluskal@suse.com
- Update to 2015.10.13:
  * Update regulatory rules for Malaysia (MY)	￼Jouni Malinen	1	-3/+4
  * Add VHT channel bandwidth for Ukraine (UA)	￼Jouni Malinen	1	-2/+3
  * Add VHT channel bandwidth for Russia (RU)	￼Jouni Malinen	1	-4/+4
  * Update regulatory rules for Uruguay (UY)	￼Jouni Malinen	1	-3/+2
  * Update 5 GHz rules for Taiwan (TW) to follow US	￼Chen-Yu Tsai	1	-2/+2
  * Add U-NII-1 (5150 ~ 5250 MHz) band for Taiwan (TW)	￼Chen-Yu Tsai	1	-1/+3
  * Update 5GHz rules for US	￼Chen-Yu Tsai	1	-1/+2
  * Update regulatory rule boundary frequencies for Taiwan (TW)	￼Chen-Yu Tsai	1	-3/+3
  * Update U-NII-2c (5470 ~ 5725 MHz) rules for Taiwan (TW)	￼Chen-Yu Tsai	1	-2/+8
  * Update ZA rules for 5490-5710 MHz
* Mon Sep 28 2015 mpluskal@suse.com
- Update to 2015.09.25:
  * Add ETSI as the DFS region for Hong Kong
* Sun Sep  6 2015 mpluskal@suse.com
- Update to 2015.07.20:
  * update CA rules for 5600 - 5650 mHz
* Sat Mar 28 2015 mpluskal@suse.com
- Update to 2015.01.30:
  * Add 60GHz regulatory rules for Russia (RU)
  * Add 60GHz regulatory rules for Japan (JP)
  * update BG rules for 5725 - 5875 mHz
* Sun Nov 16 2014 crrodriguez@opensuse.org
- Update 2014.10.07
* Sun Sep  7 2014 crrodriguez@opensuse.org
- Update to 2014.06.13
* Wed Nov 27 2013 crrodriguez@opensuse.org
- version 2013.10.11 upstream tarballs were incorrectly generated
  and contained an invalid regulatory database, update to version
  2013.11.27 in which the problem has been corrected.
* Sat Nov 23 2013 crrodriguez@opensuse.org
- update to 2013.10.11
- remove bogus Requires
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
- Cleanup spec file
- Update database to the most recent 2013.02.13
* Mon Dec 31 2012 crrodriguez@opensuse.org
- Update database to the most recent 2012.06.08
* Wed Jul 11 2012 cfarrell@suse.com
- license update: ISC
  The license in the LICENSE file is ISC, not MIT
  (http://www.spdx.org/licenses/ISC)
* Fri Jul  6 2012 cfarrell@suse.com
- license update: MIT
  Look at the COPYING file
* Fri Mar  5 2010 ro@suse.de
- update to 2009.11.25
* Wed Sep  9 2009 vlado@suse.cz
- Updated to 2009.09.08
* Tue Jul 28 2009 aj@suse.de
- Update to 2009.04.30:
  * KR,BN,DE reg updates
  * enable passive scanning for world regdomain on other channels
* Mon Feb  9 2009 hschaa@suse.de
- Update to 2009.01.30
- Needed for fate#305301
* Sat Jan 24 2009 helmut.schaa@googlemail.com
- Initial package
